@@ -11,6 +11,7 @@ class TaskResultDoesNotExist(DoesNotExistError):
 
 
 class PerformTaskError(Exception):
-    def __init__(self, exception=None, error_data=None):
+    def __init__(self, exception=None, error_data=None, task=None):
+        self.task = task
         self.exception = exception
         self.error_data = error_data
